Revision: 6215
Author: [email protected]
Date: Fri Jan  7 01:47:16 2011
Log: X64 Crankshaft: Implement some methods in LInstruction, update mjsunit test expectations.
Review URL: http://codereview.chromium.org/6118002
http://code.google.com/p/v8/source/detail?r=6215

Modified:
 /branches/bleeding_edge/src/x64/lithium-x64.h
 /branches/bleeding_edge/test/mjsunit/mjsunit.status

=======================================
--- /branches/bleeding_edge/src/x64/lithium-x64.h       Wed Jan  5 04:31:31 2011
+++ /branches/bleeding_edge/src/x64/lithium-x64.h       Fri Jan  7 01:47:16 2011
@@ -1,4 +1,4 @@
-// Copyright 2010 the V8 project authors. All rights reserved.
+// Copyright 2011 the V8 project authors. All rights reserved.
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are
 // met:
@@ -44,6 +44,9 @@
  public:
   LInstruction() { }
   virtual ~LInstruction() { }
+
+  virtual void PrintTo(StringStream* stream) const { UNIMPLEMENTED(); }
+  virtual void PrintDataTo(StringStream* stream) const { }

   // Predicates should be generated by macro as in lithium-ia32.h.
   virtual bool IsLabel() const {
@@ -55,17 +58,30 @@
     return false;
   }

-  LPointerMap* pointer_map() const {
-    UNIMPLEMENTED();
-    return NULL;
-  }
-
-  bool HasPointerMap() const {
-    UNIMPLEMENTED();
-    return false;
-  }
-
-  virtual void PrintTo(StringStream* stream) const { UNIMPLEMENTED(); }
+  void set_environment(LEnvironment* env) { environment_.set(env); }
+  LEnvironment* environment() const { return environment_.get(); }
+  bool HasEnvironment() const { return environment_.is_set(); }
+
+  void set_pointer_map(LPointerMap* p) { pointer_map_.set(p); }
+  LPointerMap* pointer_map() const { return pointer_map_.get(); }
+  bool HasPointerMap() const { return pointer_map_.is_set(); }
+
+  void set_result(LOperand* operand) { result_.set(operand); }
+  LOperand* result() const { return result_.get(); }
+  bool HasResult() const { return result_.is_set(); }
+
+  void set_hydrogen_value(HValue* value) { hydrogen_value_ = value; }
+  HValue* hydrogen_value() const { return hydrogen_value_; }
+
+  void set_deoptimization_environment(LEnvironment* env) {
+    deoptimization_environment_.set(env);
+  }
+  LEnvironment* deoptimization_environment() const {
+    return deoptimization_environment_.get();
+  }
+  bool HasDeoptimizationEnvironment() const {
+    return deoptimization_environment_.is_set();
+  }

  private:
   SetOncePointer<LEnvironment> environment_;
=======================================
--- /branches/bleeding_edge/test/mjsunit/mjsunit.status Tue Dec 14 23:46:22 2010 +++ /branches/bleeding_edge/test/mjsunit/mjsunit.status Fri Jan 7 01:47:16 2011
@@ -109,7 +109,14 @@
##############################################################################
 [ $arch == arm && $crankshaft ]

-# Test that currently fail with crankshaft on ARM.
+# Test that currently fails with crankshaft on ARM.
+compiler/simple-osr: FAIL
+
+
+##############################################################################
+[ $arch == x64 && $crankshaft ]
+
+# Test that currently fails with crankshaft on X64.
 compiler/simple-osr: FAIL


--
v8-dev mailing list
[email protected]
http://groups.google.com/group/v8-dev

Reply via email to